@@ -258,9 +258,8 @@ KScreen::ConfigPtr Generator::displaySwitch(DisplaySwitchAction action)
 
         return config;
     }
-    default:
-        // None: just return config
-        // Clone: handled above
+    case Generator::None: // just return config
+    case Generator::Clone: // handled above
         break;
     } // switch
 
